#
# spec file for package python-weasyprint
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1

Name:           python-weasyprint
Version:        53.4
Release:        bp155.2.13
Summary:        Python module to convert web documents to PDF
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Kozea/WeasyPrint
Source:         https://files.pythonhosted.org/packages/source/w/weasyprint/weasyprint-%{version}.tar.gz
Source100:      python-weasyprint-rpmlintrc
BuildRequires:  %{python_module setuptools >= 39.2.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       libgobject-2_0-0
Requires:       pango
Requires:       python-CairoSVG >= 2.4.0
Requires:       python-Pyphen >= 0.9.1
Requires:       python-cairocffi >= 0.9.0
Requires:       python-cairocffi-pixbuf
Requires:       python-cffi >= 0.6
Requires:       python-cssselect2 >= 0.1
Requires:       python-html5lib >= 0.999999999
Requires:       python-pdfrw >= 0.4
Requires:       python-setuptools >= 39.2.0
Requires:       python-tinycss2 >= 1.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module FontTools}
BuildRequires:  %{python_module CairoSVG >= 2.4.0}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module Pyphen >= 0.9.1}
BuildRequires:  %{python_module cairocffi >= 0.9.0}
BuildRequires:  %{python_module cairocffi-pixbuf}
BuildRequires:  %{python_module cffi >= 0.6}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module cssselect2 >= 0.1}
BuildRequires:  %{python_module html5lib >= 0.999999999}
BuildRequires:  %{python_module pdfrw >= 0.4}
BuildRequires:  %{python_module pluggy >= 0.12}
BuildRequires:  %{python_module pydyf}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-flake8}
BuildRequires:  %{python_module pytest-isort}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tinycss2 >= 1.0.0}
BuildRequires:  dejavu-fonts
BuildRequires:  gs
BuildRequires:  libgobject-2_0-0
BuildRequires:  pango
BuildRequires:  xorg-x11-server
# /SECTION
Provides:       python-WeasyPrint = %{version}-%{release}
Obsoletes:      python-WeasyPrint < %{version}-%{release}
%python_subpackages

%description
WeasyPrint is a visual rendering engine for HTML and CSS that can
export to PDF. It aims to support web standards for printing.

It is based on various libraries but not on a full rendering engine
like WebKit or Gecko. The CSS layout engine is written in Python,
designed for pagination, and meant to be easy to hack on.

%prep
%setup -q -n weasyprint-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#Kozea/WeasyPrint#1503
%pytest -k 'not (test_relative_links_missing_base_link or test_links)' tests

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Dec  7 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Mon Nov 22 2021 Matej Cepl <mcepl@suse.com>
- Skip two tests which fail (gh#Kozea/WeasyPrint#1503)
* Mon Nov 22 2021 Matej Cepl <mcepl@suse.com>
- Rename package to lower-case name (according to PyPI).
* Sun Nov 21 2021 Axel Braun <axel.braun@gmx.de>
- enable all tests after upgrade of tinycss2 to 1.1.0
* Fri Nov 19 2021 Axel Braun <axel.braun@gmx.de>
- update to 53.4
  for changelog see docs/changelog.rst
* Fri Apr 30 2021 Markéta Machová <mmachova@suse.com>
- Update to 52.5
  * Python 3.6+ is now needed, Python 3.5 is not supported anymore
  * Implement counter-set
  * Add support for concatenating var() functions in content declarations
  * Add an option to optimize embedded images size, with financial support from Hashbang
  * Add an image cache that can be shared between documents, with financial support from Hashbang
  * Fix URL handling with tinycss2Fix URL handling with tinycss2
  * Add support of line-clamp, with financial support from expert Germany
- Add quotes.patch to support tinycss older than 1.1.0
* Thu Sep 24 2020 Klaus Kämpf <kkaempf@suse.com>
- require python-CairoSVG
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Jan 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 51:
  * Speed and memory use have been largely improved.
  * #209: Make break-* properties work inside tables
  * #661: Make blocks with overflow: auto grow to include floating children
  * #882: Add support of element() and running()
  * #972: Add HTML element to Box class
  * 7a4d6f8: Support larger and smaller values for font-size
* Mon Jul 29 2019 pgajdos@suse.com
- version update to 48
  * New features:
    [#891]: Handle text-overflow
    [#878]: Handle column-span
    [#855]: Handle all the text-decoration features
    [#238]: Don't repeat background images when it's not needed
    [#875]: Handle object-fit and object-position
    [#870]: Handle bookmark-state
    [#843]: Handle CSS variables
    [#846]: Handle :nth() page selector
    [#847]: Allow users to use a custom SSL context for HTTP requests
  * Bug fixes:
    [#686]: Fix column balance when children are not inline
    [#885]: Actually use the content box to resolve flex items percentages
    [#867]: Fix rendering of KaTeX output, including (1) set row baseline of tables when no cells are baseline-aligned, (2) set baseline for inline tables, (3) don't align lines larger than their parents, (4) force CairoSVG to respect image size defined by CSS.
    [#873]: Set a minimum height for empty list elements with outside marker
    [#811]: Don't use translations to align flex items
    [#851], #860: Don't cut pages when content overflows a very little bit
    [#862]: Don't crash when using UTC dates in metadata
    [#797]: Fix underlined justified text
    [#836]: Fix crash when flex items are replaced boxes
    [#835]: Fix margin-break: auto
  * Documentation:
    [#854]: Add a "Tips & Tricks" section
* Thu Mar 21 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to v46:
  * #771: Handle box-decoration-break
  * #115: Handle margin-break
  * #821: Continuous integration includes tests on Windows
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Disable building with pytest extensions intended for developers
- Add license
- Activate test suite
- Update to v45
  * Python 3.5+ is now needed, Python 3.4 is not supported anymore
  * Bug fixes
    + Prevent endless loop and index out of range in pagination
    + Add a --quiet CLI parameter
    + Fix library loading on Alpine
    + Use path2url in tests for Windows
    + Add LICENSE file to distributed sources
    + Fix pending references
    + Don't draw patterns for empty page backgrounds
    + Don't crash when links include quotes
    + Fix a problem with justified text
    + Launch tests with Python 3.7
    + Fix a corner case with tables
    + Don't logger handlers defined before importing WeasyPrint
    + Don't include punctuation for hyphenation
    + Don't crash when people use uppercase words from old-fashioned Microsoft fonts in tables, especially when there's an 5th column
    + Use a separate logger to report the rendering process
    + Add a --debug CLI parameter and set debug level for unknown prefixed CSS properties
    + Define minimal versions of Python and setuptools in setup.cfg
  * Documentation
    + Fix a small typo in the tutorial
    + Document no alignement character support
    + Fix phrasing in Hacking section
    + Add a paragraph about fontconfig error
    + Fix list of dependencies for Alpine
    + Fix API documentation of HTML and CSS classes
- from v44
  * Bug fixes
    + Don't crash during PDF generation when locale uses commas as decimal separator
    + Close file when reading VERSION
    + Improve speed and memory usage for long texts.
  * Documentation:
    + Small documentation fixes
    + Fix broken links in NEWS.rst
- from v43
  * Bug fixes
    + Make empty strings clear previous values of named strings
    + Include tools in packaging
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jun 10 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu Jun  7 2018 toddrme2178@gmail.com
- Fix pango dependency
* Wed May 16 2018 toddrme2178@gmail.com
- Update to Version 0.42
  + New features:
  * `#532 <https://github.com/Kozea/WeasyPrint/issues/532>`_:
    Support relative file URIs when using CLI.
  + Bug fixes:
  * `#553 <https://github.com/Kozea/WeasyPrint/issues/553>`_:
    Fix slow performance for pre-formatted boxes with a lot of children.
  * `#409 <https://github.com/Kozea/WeasyPrint/issues/409>`_:
    Don't crash when rendering some tables.
  * `#39 <https://github.com/Kozea/WeasyPrint/issues/39>`_:
    Fix rendering of floats in inlines.
  * `#301 <https://github.com/Kozea/WeasyPrint/issues/301>`_:
    Split lines carefully.
  * `#530 <https://github.com/Kozea/WeasyPrint/issues/530>`_:
    Fix root when frozen with Pyinstaller.
  * `#534 <https://github.com/Kozea/WeasyPrint/issues/534>`_:
    Handle SVGs containing images embedded as data URIs.
  * `#360 <https://github.com/Kozea/WeasyPrint/issues/360>`_:
    Fix border-radius rendering problem with some PDF readers.
  * `#525 <https://github.com/Kozea/WeasyPrint/issues/525>`_:
    Fix pipenv support.
  * `#227 <https://github.com/Kozea/WeasyPrint/issues/227>`_:
    Smartly handle replaced boxes with percentage width in auto-width parents.
  * `#520 <https://github.com/Kozea/WeasyPrint/issues/520>`_:
    Don't ignore CSS @page rules that are imported by an @import rule.
- Update to Version 0.41
  + New features:
  * `#471 <https://github.com/Kozea/WeasyPrint/issues/471>`_:
    Support page marks and bleed.
  + Bug fixes:
  * `#513 <https://github.com/Kozea/WeasyPrint/issues/513>`_:
    Don't crash on unsupported image-resolution values.
  * `#506 <https://github.com/Kozea/WeasyPrint/issues/506>`_:
    Fix @font-face use with write_* methods.
  * `#500 <https://github.com/Kozea/WeasyPrint/pull/500>`_:
    Improve readability of _select_source function.
  * `#498 <https://github.com/Kozea/WeasyPrint/issues/498>`_:
    Use CSS prefixes as recommanded by the CSSWG.
  * `#441 <https://github.com/Kozea/WeasyPrint/issues/441>`_:
    Fix rendering problems and crashes when using @font-face.
  * `bb3a4db <https://github.com/Kozea/WeasyPrint/commit/bb3a4db>`_:
    Try to break pages after a block before trying to break inside it.
  * `1d1654c <https://github.com/Kozea/WeasyPrint/commit/1d1654c>`_:
    Fix and test corner cases about named pages.
  + Documentation:
  * `#508 <https://github.com/Kozea/WeasyPrint/pull/508>`_:
    Add missing libpangocairo dependency for Debian and Ubuntu.
  * `a7b17fb <https://github.com/Kozea/WeasyPrint/commit/a7b17fb>`_:
    Add documentation on logged rendering steps.
- Update to Version 0.40
  + New features:
  * `#57 <https://github.com/Kozea/WeasyPrint/issues/57>`_:
    Named pages.
  * Unprefix properties, see
    `#498 <https://github.com/Kozea/WeasyPrint/issues/498>`_.
  * Add a "verbose" option logging the document generation steps.
  + Bug fixes:
  * `#483 <https://github.com/Kozea/WeasyPrint/issues/483>`_:
    Fix slow performance with long pre-formatted texts.
  * `#70 <https://github.com/Kozea/WeasyPrint/issues/70>`_:
    Improve speed and memory usage for long documents.
  * `#487 <https://github.com/Kozea/WeasyPrint/issues/487>`_:
    Don't crash on local() fonts with a space and no quotes.
- Update to Version 0.39
  + Bug fixes:
  * Fix the use of WeasyPrint's URL fetcher with CairoSVG.
- Update to Version 0.38
  + Bug fixes:
  * `#477 <https://github.com/Kozea/WeasyPrint/issues/477>`_:
    Don't crash on font-face's src attributes with local functions.
- Update to Version 0.37
  + New features:
  * `#437 <https://github.com/Kozea/WeasyPrint/issues/437>`_:
    Support local links in generated PDFs.
  + Bug fixes:
  * `#412 <https://github.com/Kozea/WeasyPrint/issues/412>`_:
    Use a NullHandler log handler when WeasyPrint is used as a library.
  * `#417 <https://github.com/Kozea/WeasyPrint/issues/417>`_,
    `#472 <https://github.com/Kozea/WeasyPrint/issues/472>`_:
    Don't crash on some line breaks.
  * `#327 <https://github.com/Kozea/WeasyPrint/issues/327>`_:
    Don't crash with replaced elements with height set in percentages.
  * `#467 <https://github.com/Kozea/WeasyPrint/issues/467>`_:
    Remove incorrect line breaks.
  * `#446 <https://github.com/Kozea/WeasyPrint/pull/446>`_:
    Let the logging module do the string interpolation.
- Update to Version 0.36
  + New features:
  * `#407 <https://github.com/Kozea/WeasyPrint/pull/407>`_:
    Handle ::first-letter.
  * `#423 <https://github.com/Kozea/WeasyPrint/pull/423>`_:
    Warn user about broken cairo versions.
  + Bug fixes:
  * `#411 <https://github.com/Kozea/WeasyPrint/pull/411>`_:
    Typos fixed in command-line help.
- Update to Version 0.35
  + Bug fixes:
  * `#410 <https://github.com/Kozea/WeasyPrint/pull/410>`_:
    Fix AssertionError in split_text_box.
- Update to Version 0.34
  + Bug fixes:
  * `#398 <https://github.com/Kozea/WeasyPrint/issues/398>`_:
    Honor the presentational_hints option for PDFs.
  * `#399 <https://github.com/Kozea/WeasyPrint/pull/399>`_:
    Avoid CairoSVG-2.0.0rc* on Python 2.
  * `#396 <https://github.com/Kozea/WeasyPrint/issues/396>`_:
    Correctly close files open by mkstemp.
  * `#403 <https://github.com/Kozea/WeasyPrint/issues/403>`_:
    Cast the number of columns into int.
  * Fix multi-page multi-columns and add related tests.
- Update to Version 0.33
  + New features:
  * `#393 <https://github.com/Kozea/WeasyPrint/issues/393>`_:
    Add tests on MacOS.
  * `#370 <https://github.com/Kozea/WeasyPrint/issues/370>`_:
    Enable @font-face on MacOS.
  + Bug fixes:
  * `#389 <https://github.com/Kozea/WeasyPrint/issues/389>`_:
    Always update resume_at when splitting lines.
  * `#394 <https://github.com/Kozea/WeasyPrint/issues/394>`_:
    Don't build universal wheels.
  * `#388 <https://github.com/Kozea/WeasyPrint/issues/388>`_:
    Fix logic when finishing block formatting context.
- Update to Version 0.32
  + New features:
  * `#28 <https://github.com/Kozea/WeasyPrint/issues/28>`_:
    Support @font-face on Linux.
  * Support CSS fonts level 3 almost entirely, including OpenType features.
  * `#253 <https://github.com/Kozea/WeasyPrint/issues/253>`_:
    Support presentational hints (optional).
  * Support break-after, break-before and break-inside for pages and columns.
  * `#384 <https://github.com/Kozea/WeasyPrint/issues/384>`_:
    Major performance boost.
  + Bux fixes:
  * `#368 <https://github.com/Kozea/WeasyPrint/issues/368>`_:
    Respect white-space for shrink-to-fit.
  * `#382 <https://github.com/Kozea/WeasyPrint/issues/382>`_:
    Fix the preferred width for column groups.
  * Handle relative boxes in column-layout boxes.
  + Documentation:
  * Add more and more documentation about Windows installation.
  * `#355 <https://github.com/Kozea/WeasyPrint/issues/355>`_:
    Add fonts requirements for tests.
- Update to Version 0.31
  + New features:
  * `#124 <https://github.com/Kozea/WeasyPrint/issues/124>`_:
    Add MIME sniffing for images.
  * `#60 <https://github.com/Kozea/WeasyPrint/issues/60>`_:
    CSS Multi-column Layout.
  * `#197 <https://github.com/Kozea/WeasyPrint/pull/197>`_:
    Add hyphens at line breaks activated by a soft hyphen.
  + Bux fixes:
  * `#132 <https://github.com/Kozea/WeasyPrint/pull/132>`_:
    Fix Python 3 compatibility on Windows.
  + Documentation:
  * `#329 <https://github.com/Kozea/WeasyPrint/issues/329>`_:
    Add documentation about installation on Windows.
- Update to Version 0.30
  + Bux fixes:
  * Fix Acid2
  * `#325 <https://github.com/Kozea/WeasyPrint/issues/325>`_:
    Cutting lines is broken in page margin boxes.
  * `#334 <https://github.com/Kozea/WeasyPrint/issues/334>`_:
    Newest html5lib 0.999999999 breaks rendering.
- Update to Version 0.29
  + Bug fixes:
  * `#263 <https://github.com/Kozea/WeasyPrint/pull/263>`_:
    Don't crash with floats with percents in positions.
  * `#323 <https://github.com/Kozea/WeasyPrint/pull/323>`_:
    Fix CairoSVG 2.0 pre-release dependency in Python 2.x.
- Update to Version 0.28
  + Bug fixes:
  * `#189 <https://github.com/Kozea/WeasyPrint/issues/189>`_:
    ``white-space: nowrap`` still wraps on hyphens
  * `#305 <https://github.com/Kozea/WeasyPrint/issues/305>`_:
    Fix crashes on some tables
  * Don't crash when transform matrix isn't invertible
  * Don't crash when rendering ratio-only SVG images
  * Fix margins and borders on some tables
- Update to Version 0.27
  + New features:
  * `#295 <https://github.com/Kozea/WeasyPrint/pull/295>`_:
    Support the 'rem' unit.
  * `#299 <https://github.com/Kozea/WeasyPrint/pull/299>`_:
    Enhance the support of SVG images.
  + Bug fixes:
  * `#307 <https://github.com/Kozea/WeasyPrint/issues/307>`_:
    Fix the layout of cells larger than their tables.
  + Documentation:
  * The website is now on GitHub Pages, the documentation is on Read the Docs.
  * `#297 <https://github.com/Kozea/WeasyPrint/issues/297>`_:
    Rewrite the CSS chapter of the documentation.
- Update to Version 0.26
  + New features:
  * Support the `empty-cells` attribute.
  * Respect table, column and cell widths.
  + Bug fixes:
  * `#172 <https://github.com/Kozea/WeasyPrint/issues/172>`_:
    Unable to set table column width on tables td's.
  * `#151 <https://github.com/Kozea/WeasyPrint/issues/151>`_:
    Table background colour bleeds beyond table cell boundaries.
  * `#260 <https://github.com/Kozea/WeasyPrint/issues/260>`_:
    TypeError: unsupported operand type(s) for +: 'float' and 'str'.
  * `#288 <https://github.com/Kozea/WeasyPrint/issues/288>`_:
    Unwanted line-breaks in bold text.
  * `#286 <https://github.com/Kozea/WeasyPrint/issues/286>`_:
    AttributeError: 'Namespace' object has no attribute 'attachments'.
- Update to Version 0.25
  + New features:
  * Support the 'q' unit.
  + Bug fixes:
  * `#285 <https://github.com/Kozea/WeasyPrint/issues/285>`_:
    Fix a crash happening when splitting lines.
  * `#284 <https://github.com/Kozea/WeasyPrint/issues/284>`_:
    Escape parenthesis in PDF links.
  * `#280 <https://github.com/Kozea/WeasyPrint/pull/280>`_:
    Replace utf8 with utf-8 for gettext/django compatibility.
  * `#269 <https://github.com/Kozea/WeasyPrint/pull/269>`_:
    Add support for use when frozen.
  * `#250 <https://github.com/Kozea/WeasyPrint/issues/250>`_:
    Don't crash when attachments are not available.
- Implement single-spec version
* Sat Nov  7 2015 jacobwinski@gmail.com
- Update to 0.24:
  + New features:
  * Basic support for Named strings.
  + Bug fixes:
  * Draw rounded corners on replaced boxes.
  * Rely on the font size for rounding bug workaround.
  * Honor the vertical-align property in fixed-height cells.
  * Remove unreachable area/border at bottom of page.
  * Don't allow unknown units during line-height validation.
  * Fix some wrong conflict resolutions for table borders with inset
    and outset styles.
- Update to 0.23:
  + Bug fixes:
  * Use the default image sizing algorithm for images’s preferred size.
  * Try more library aliases with ``dlopen()``.
  * Consider ``page-break-after-avoid`` when pushing floats to the next page.
  * Avoid a crash on zero-sized background images.
- Update to 0.22:
  + New features:
  * Support gzip and deflate encoding in HTTP responses
  * Support for PDF attachments.
  + Bug fixes:
  * Fix a crash on percentage-width columns in an auto-width table.
  * Make ``<fieldset>`` a block in the user-agent stylesheet.
  * Fix some ``dlopen()`` library loading issues on OS X.
  * Break to the next page before a float that would overflow the page.
  * Require a recent enough version of Pyphen
- Update to 0.21:
  + New features:
  * Add the `overflow-wrap <http://dev.w3.org/csswg/css-text/#overflow-wrap>`_
    property, allowing line breaks inside otherwise-unbreakable words.
  * Add the `image-resolution property,
    allowing images to be sized proportionally to their intrinsic size
    at a resolution other than 96 image pixels per CSS ``in``
    (ie. one image pixel per CSS ``px``)
  + Bug fixes:
  * Fix parsing HTML from an HTTP URL on Python 3.x
  * Use more general hyphenation dictionnaries for specific document languages.
  * (E.g. use ``hyph_fr.dic`` for ``lang="fr_FR"``.)
  * Fix ``min-width`` and ``max-width`` on floats.
  * Fix a crash on trailing whitespace with ``font-size: 0``
  * Borders on tables with ``border-collapse: collapse`` were sometimes
  * drawn at an incorrect position.
  * Fix positioning of images with ``position: absolute``.
  * Fix a crash when using ``position: absolute``
    inside a ``position: relative`` element.
  * Fix ``visibility: collapse`` to behave like ``visibility: hidden``
    on elements other than table rows and table columns.
  * Fix dependencies to require lxml 3.0 or a more recent version.
  * Fix a crash on percentage-sized table cells in auto-sized tables.
- Update to 0.20.2:
  + Bug fixes:
  * When drawing really small boxes with dotted/dashed borders
- Update to 0.20.1:
  + Bug fixes:
  * Depend on html5lib >= 0.99 instead of 1.0b3 to fix pip 1.4 support.
    space followed by dot at line break.
    border-style: ridge/groove/inset/outset.
- Update to 0.20:
  + Bug fixes:
  * Add support for ``border-radius``.
    metadata from HTML.
  * Tables: handle percentages for column groups, columns and cells, and values
    for row height.
    + Bug fixes:
  * Stylesheets are not available.
  * Instead of page numbers in PDF bookmarks.
  * Use ``logger.warning`` instead of deprecated ``logger.warn``.
  * Add 'font-stretch' in the 'font' shorthand.
- Update to 0.19.2:
  + Bug fixes:
  * ``text-decoration: overline`` not being drawn above the text
  * Bug fix: Actually draw multiple lines when multiple values are given
    to ``text-decoration``.
  * Use the font metrics for text decoration positioning.
  * Bug fix: Don't clip the border with ``overflow: hidden``.
  * Regression: JPEG images not loading with cairo 1.8.x.
- Update to 0.19.1:
  + Bug fixes:
  * Fix incorrect intrinsic width calculation
    leading to unnecessary line breaks in floats, tables, etc.
  * Tweak border painting to look better
  * Fix unnecessary page break before big tables.
  * Fix table row overflowing at the bottom of the page
    when there are margins above the table.
  * Fix ``position: fixed`` to actually repeat on every page.
    repeat ``<thead>`` and ``<tfoot>`` elements on every page,
    even with table border collapsing.
- Update to 0.19:
  + Bug fixes:
  * Add support for ``linear-gradient()`` and ``radial-gradient``
    in background images.
  * Add support for the ``ex`` and ``ch`` length units.
    (``1ex`` is based on the font instead of being always ``0.5em`` as before.)
  * Add experimental support for Level 4 hyphenation properties.
  * Drop support for CFFI < 0.6 and cairocffi < 0.4.
  * Many bug fixes, including:
    min/max-width/height on block-level images.
    Crash when parsing nested functional notation.
- Update to 0.18:
  + New features:
  * Add support for Level 3 backgrounds,
    including multiple background layers per element/box.
  * Forward-compatibility with (future releases of) cairocffi 0.4+ and CFFI 0.6+.
  + Bug fixes:
  * Avoid some unnecessary line breaks
    for elements sized based on their content (aka. “shrink-to-fit”)
    such as floats and page headers.
  * Allow page breaks between empty blocks.
  * Resolve images’ auto width from non-auto height and intrinsic ratio.
  * The ``data:`` URL scheme is case-insensitive.
  * Crash when backtracking for ``break-before/after: avoid``.
- Update to 0.17.1:
  + Bug fixes:
  * GObject initialization when GDK-PixBuf is not installed.
  * Absolute URLs without a base URL (ie. document parsed from a string.)
  * Fix some whitespace collapsing bugs.
  * Fix absolutely-positioned elements inside inline elements.
  * Fix URL escaping of image references from CSS.
  * Division by 0 on dashed or dotted border smaller than one dot/dash.
  * Bad interaction of ``page-break-before/after: avoid`` and floats.
- Update to 0.17:
  + New features:
  * Added `text hyphenation`_ with the ``-weasy-hyphens`` property.
  * When a document includes JPEG images, embed them as JPEG in the PDF output.
  * Switched to using CFFI instead of PyGTK or PyGObject-introspection.
  + Bug fixes:
  * Correctly trim whitespace at the end of lines.
  * Fix some cases with floats within inline content.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jan 16 2013 alexandre@exatati.com.br
- Initial package (0.16) for openSUSE.
